Ladsgroup has uploaded a new change for review.

  https://gerrit.wikimedia.org/r/84007


Change subject: A little description about not showing characters when you type 
passwords, which always confuses people
......................................................................

A little description about not showing characters when you type passwords, 
which always confuses people

implemented partially from [1]

[1] https://gerrit.wikimedia.org/r/#/c/79730/4/pywikibot/login.py

Change-Id: I6569fcb244f2bb19e6e6b34cc769c187a0e1b2eb
---
M login.py
1 file changed, 4 insertions(+), 3 deletions(-)


  git pull ssh://gerrit.wikimedia.org:29418/pywikibot/compat 
refs/changes/07/84007/1

diff --git a/login.py b/login.py
index 49befc8..a0b5aaa 100644
--- a/login.py
+++ b/login.py
@@ -302,7 +302,8 @@
             # As we don't want the password to appear on the screen, we set
             # password = True
             self.password = pywikibot.input(
                                 u'Password for user %(name)s on %(site)s:'
                                 % {'name': self.username, 'site': self.site},
                                 password = True)
 
@@ -372,8 +373,8 @@
     for arg in pywikibot.handleArgs():
         if arg.startswith("-pass"):
             if len(arg) == 5:
-                password = pywikibot.input(u'Password for all accounts:',
-                                           password = True)
+                password = pywikibot.input(u'Password for all accounts ' \
+                    u'(no characters will be shown):', password = True)
             else:
                 password = arg[6:]
         elif arg == "-clean":
@@ -302,7 +302,8 @@
             # password = True
             self.password = pywikibot.input(
-                                u'Password for user %(name)s on %(site)s:'
+                                u'Password for user %(name)s on %(site)s:' \
+                                u' (no characters will be shown):'
                                 % {'name': self.username, 'site': self.site},
                                 password = True)

-- 
To view, visit https://gerrit.wikimedia.org/r/84007
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: I6569fcb244f2bb19e6e6b34cc769c187a0e1b2eb
Gerrit-PatchSet: 1
Gerrit-Project: pywikibot/compat
Gerrit-Branch: master
Gerrit-Owner: Ladsgroup <[email protected]>

_______________________________________________
MediaWiki-commits mailing list
[email protected]
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to